@@ -6,6 +6,7 @@
 @File: scanalive.py
 @Time: 2022/2/24 10:47
 """
+import os
 
 import nmap
 
@@ -21,3 +22,9 @@ class Scan_Alive_Ip:
                 for port in nm[host][proto].keys():
                     self.alive_data_params = {"ip": ip, "port":port, "state":nm[host][proto][port]['state']}
         return self.alive_data_params
+
+    def scan_cobaltstrike_status(self, ip, port):
+        nm = nmap.PortScanner()
+        nse_path = str(os.path.abspath(os.path.dirname(os.path.dirname(__file__))) + "/lib/grab_beacon_config").replace("\\","/")
+        result = nm.scan(ip, port, "--script={}".format(nse_path))
+        return result
\ No newline at end of file
